Enum trillium_http_types::cache::ClearDirective [−][src]
pub enum ClearDirective {
Cache,
Cookies,
Storage,
ExecutionContexts,
}Expand description
An HTTP Clear-Site-Data directive.
Variants
Indicates that the server wishes to remove locally cached data (i.e. the browser cache, see HTTP caching) for the origin of the response URL. Depending on the browser, this might also clear out things like pre-rendered pages, script caches, WebGL shader caches, or address bar suggestions.
Indicates that the server wishes to remove all cookies for the origin of the response URL. HTTP authentication credentials are also cleared out. This affects the entire registered domain, including subdomains. So https://example.com as well as https://stage.example.com, will have cookies cleared.
Indicates that the server wishes to remove all DOM storage for the origin of the response URL.
Indicates that the server wishes to reload all browsing contexts for the origin of the response (Location.reload).
Implementations