Struct trillium_http_types::conditional::IfNoneMatch[][src]

pub struct IfNoneMatch { /* fields omitted */ }
Apply the HTTP method if the ETags do not match.

This is used to update caches or to prevent uploading a new resource when one already exists.

Specifications

Examples

use http_types::Response;
use http_types::conditional::{IfNoneMatch, ETag};

let mut entries = IfNoneMatch::new();
entries.push(ETag::new("0xcafebeef".to_string()));
entries.push(ETag::new("0xbeefcafe".to_string()));

let mut res = Response::new(200);
res.insert_header(&entries, &entries);

let entries = IfNoneMatch::from_headers(res)?.unwrap();
let mut entries = entries.iter();
assert_eq!(entries.next().unwrap(), &ETag::new("0xcafebeef".to_string()));
assert_eq!(entries.next().unwrap(), &ETag::new("0xbeefcafe".to_string()));

Implementations

Create a new instance of IfNoneMatch.

Create a new instance from headers.

Push a directive into the list of entries.

Returns true if a wildcard directive was set.

Set the wildcard directive.

An iterator visiting all server entries.

An iterator visiting all server entries.