Struct trillium_http_types::headers::HeaderName [−][src]
pub struct HeaderName(_);
A header name.
Implementations
Create a new HeaderName from a Vec of ASCII bytes.
Error
This function will error if the bytes is not valid ASCII.
Create a new HeaderName from an ASCII string.
Error
This function will error if the string is not valid ASCII.
Converts a vector of bytes to a HeaderName without checking that the string contains
valid ASCII.
Safety
This function is unsafe because it does not check that the bytes passed to it are valid ASCII. If this constraint is violated, it may cause memory unsafety issues with future users of the HeaderName, as the rest of the library assumes that Strings are valid ASCII.