Struct trillium_http_types::headers::HeaderValue [−][src]
pub struct HeaderValue { /* fields omitted */ }Expand description
A header value.
Implementations
Create a new HeaderValue from a Vec of ASCII bytes.
Error
This function will error if the bytes is not valid ASCII.
Converts a vector of bytes to a HeaderValue without checking that the string contains
valid ASCII.
Safety
This function is unsafe because it does not check that the bytes passed to it are valid ASCII. If this constraint is violated, it may cause memory unsafety issues with future users of the HeaderValue, as the rest of the library assumes that Strings are valid ASCII.