Struct trillium_http_types::headers::HeaderValues [−][src]
pub struct HeaderValues { /* fields omitted */ }Expand description
A list of HeaderValues.
This always contains at least one header value.
Implementations
Move all values from other into self, leaving other empty.
Returns a reference or a value depending on the type of index.
Returns a mutable reference or a value depending on the type of index.
Returns true if there is a value corresponding to the specified HeaderValue in the list,
false otherwise.
Returns the last HeaderValue.
Methods from Deref<Target = HeaderValue>