Struct trillium_http_types::other::Referer[][src]

pub struct Referer { /* fields omitted */ }
Contains the address of the page making the request.

Important: Although this header has many innocent uses it can have undesirable consequences for user security and privacy.

MDN Documentation

Specifications

Examples

use http_types::{Response, Url};
use http_types::other::Referer;

let referer = Referer::new(Url::parse("https://example.net/")?);

let mut res = Response::new(200);
res.insert_header(&referer, &referer);

let base_url = Url::parse("https://example.net/")?;
let referer = Referer::from_headers(base_url, res)?.unwrap();
assert_eq!(referer.location(), &Url::parse("https://example.net/")?);

Implementations

Create a new instance of Referer header.

Create a new instance from headers.

Get the url.

Set the url.